@@ -17,20 +17,20 @@ use tokio::sync::{mpsc, oneshot};
 
 use rustdb::{
     c_value, check_types, AccessPagedData, Block, CExp, CExpPtr, CompileFunc, DataKind, Database,
-    EvalEnv, Expr, GenQuery, Part, SharedPagedData, SimpleFileStorage, Value, DB, INITSQL,
+    EvalEnv, Expr, GenTransaction, Part, SharedPagedData, SimpleFileStorage, Value, DB, INITSQL,
 };
 
 use std::{collections::BTreeMap, rc::Rc, sync::Arc, thread};
 
 /// Query to be sent to server thread, implements IntoResponse.
 struct ServerQuery {
-    pub x: Box<GenQuery>,
+    pub x: Box<GenTransaction>,
 }
 
 impl ServerQuery {
     pub fn new() -> Self {
         Self {
-            x: Box::new(GenQuery::new()),
+            x: Box::new(GenTransaction::new()),
         }
     }
 }
@@ -68,10 +68,16 @@ async fn main() {
     let spd = Arc::new(SharedPagedData::new(sfs));
 
     let (tx, mut rx) = mpsc::channel::<ServerMessage>(1);
+    let (log_tx, log_rx) = std::sync::mpsc::channel::<String>();
 
     let state = Arc::new(SharedState { tx, spd });
     let wapd = state.spd.open_write();
 
+    // This is the logging thread *synchronous)
+    thread::spawn(move || {
+        log_loop(log_rx);
+    });
+
     // This is the server thread (synchronous).
     thread::spawn(move || {
         let db = get_db(wapd, INITSQL);
@@ -81,8 +87,9 @@ async fn main() {
             let updates = db.save();
             if updates > 0 {
                 println!("Pages updated={}", updates);
-                let ser = serde_json::to_string(&sm.sq.x).unwrap();
-                println!("Serialised query={}", ser);
+                let ser = serde_json::to_string(&sm.sq.x.qy).unwrap();
+                // println!("Serialised query={}", ser);
+                let _err = log_tx.send(ser);
             }
             let _x = sm.tx.send(sm.sq);
         }
@@ -156,9 +163,9 @@ async fn h_get(
 ) -> ServerQuery {
     // Build the ServerQuery.
     let mut sq = ServerQuery::new();
-    sq.x.path = path.0;
-    sq.x.params = params.0;
-    sq.x.cookies = map_cookies(cookies);
+    sq.x.qy.path = path.0;
+    sq.x.qy.params = params.0;
+    sq.x.qy.cookies = map_cookies(cookies);
 
     let blocking_task = tokio::task::spawn_blocking(move || {
         // GET requests should be read-only.
@@ -181,13 +188,13 @@ async fn h_post(
 ) -> ServerQuery {
     // Build the ServerQuery.
     let mut sq = ServerQuery::new();
-    sq.x.path = path.0;
-    sq.x.params = params.0;
-    sq.x.cookies = map_cookies(cookies);
+    sq.x.qy.path = path.0;
+    sq.x.qy.params = params.0;
+    sq.x.qy.cookies = map_cookies(cookies);
     if let Some(Form(form)) = form {
-        sq.x.form = form;
+        sq.x.qy.form = form;
     } else {
-        sq.x.parts = map_parts(multipart).await;
+        sq.x.qy.parts = map_parts(multipart).await;
     }
 
     // Send query to database thread ( and get it back ).
@@ -209,11 +216,11 @@ impl IntoResponse for ServerQuery {
     type BodyError = std::convert::Infallible;
 
     fn into_response(self) -> Response<Self::Body> {
-        let mut res = Response::new(Full::from(self.x.output));
+        let mut res = Response::new(Full::from(self.x.rp.output));
 
-        *res.status_mut() = StatusCode::from_u16(self.x.status_code).unwrap();
+        *res.status_mut() = StatusCode::from_u16(self.x.rp.status_code).unwrap();
 
-        for (name, value) in &self.x.headers {
+        for (name, value) in &self.x.rp.headers {
             res.headers_mut().insert(
                 HeaderName::from_lowercase(name.as_bytes()).unwrap(),
                 HeaderValue::from_str(value).unwrap(),
@@ -249,3 +256,18 @@ impl CExp<Value> for Argon {
         Value::RcBinary(Rc::new(result))
     }
 }
+
+use std::{fs::OpenOptions, io::Write};
+fn log_loop(log_rx: std::sync::mpsc::Receiver<String>) {
+    let filename = "C:/Users/pc/rust/sftest01.logfile";
+    let mut logfile = OpenOptions::new()
+        .append(true)
+        .create(true)
+        .open(filename)
+        .unwrap();
+    loop {
+        let logstr = log_rx.recv().unwrap();
+        let _err = logfile.write_all(logstr.as_bytes());
+        let _err = logfile.write_all(b"\r\n");
+    }
+}
